Learn R Programming

ramcmc (version 0.1.2)

chol_downdate: Rank-one Downdate of Cholesky Decomposition

Description

Given the lower triangular matrix L obtained from the Cholesky decomposition of A, function chol_downdate updates L such that it corresponds to the decomposition of A - u*u' (if such decomposition exists).

Usage

chol_downdate(L, u)

Arguments

L

A lower triangular matrix. Strictly upper diagonal part is not referenced.

u

A vector with with length matching with the dimensions of L.

Value

Updated L.