Given the lower triangular matrix L obtained from the Cholesky decomposition of A,
function chol_downdate updates L such that it corresponds to the decomposition of A - u*u'
(if such decomposition exists).
chol_downdate(L, u)A lower triangular matrix. Strictly upper diagonal part is not referenced.
A vector with with length matching with the dimensions of L.
Updated L.